#!/usr/bin/env python
import pandas as pd
from abromics_galaxy_json_extractor.interfaces import (
    AbromicsResultIterator,
)

required_metadata = {
    "analysis_software_version": "abricate version",
    "reference_database_version": "DB version",
    "hid": "historic ID for abricate file from galaxy",
}


class AbricateIterator(AbromicsResultIterator):
    """Abricate tool parser
        Extract all results from abricate report.tsv file
        Args:
        AbromicsResultIterator (abc.ABCMeta): abstract class to the parser
    """
    def __init__(self, source, metadata):
        metadata["analysis_software_name"] = "abricate"
        self.metadata = metadata
        super().__init__(source, self.metadata)
        self.abromics_results["tool_has_database"] = True
        self.parse()

    def parse(self):
        """
            Extract header of file and related results
        """
        reader = pd.read_table(self.stream, header=0, sep="\t")
        reader.columns = reader.columns.str.replace("#", "", regex=True)
        reader.columns = reader.columns.str.lower()
        reader = reader.drop(["coverage_map"], axis=1)
        reader["resistance"].fillna("", inplace=True)
        extract_length = reader.coverage.str.split("/", expand=True)
        if len(extract_length) > 0:
            reader["length"] = extract_length[1]
        reader = reader.to_dict(orient="records")
        self.abromics_results["results"][0]["content"] = reader
